@@ -17,8 +17,8 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifndef GLOM_VARIABLESMAP_H
-#define GLOM_VARIABLESMAP_H
+#ifndef _GLOM_VARIABLESMAP_H
+#define _GLOM_VARIABLESMAP_H
 
 #include <gtkmm/builder.h>
 #include <map>
@@ -36,7 +36,7 @@ namespace Glom
  *
  * Gtk::Entry --> Glib::ustring
  * Gtk::SpinBox --> Glib::ustring
- * Gtk::ComboBoxEntry --> Glib::ustring
+ * Gtk::ComboBox --> Glib::ustring
  * Gtk::Scale --> double
  * Gtk::Calendar --> Glib::Date
  * Gtk::CheckBox --> bool
@@ -52,7 +52,7 @@ public:
   ///For ToggleButton (CheckBox and RadioButton)
   void connect_widget(const Glib::ustring& widget_name, bool& variable);
 
-  ///For Entry, ComboBoxEntry and SpinBox
+  ///For Entry, ComboBox and SpinBox
   void connect_widget(const Glib::ustring& widget_name, Glib::ustring& variable);
 
   ///For Scale (HScale and VScale)
@@ -85,4 +85,6 @@ protected:
 } /* namespace Glom */
 
 
-#endif /* GLOM_VARIABLESMAP_H */
+#endif /* _GLOM_VARIABLESMAP_H */
+
+
